@@ -61,7 +61,8 @@ class Server(object):
     A Server object can be used like any `dict` object.
     """
     
-    def __init__(self, uri='http://127.0.0.1:5984', uuid_batch_count=DEFAULT_UUID_BATCH_COUNT, 
+    def __init__(self, uri='http://127.0.0.1:5984', 
+            uuid_batch_count=DEFAULT_UUID_BATCH_COUNT, 
             transport=None, use_proxy=False, timeout=300, min_size=0, 
             max_size=4, pool_class=None):
         """ constructor for Server object
@@ -91,7 +92,7 @@ class Server(object):
         self._uuid_batch_count = uuid_batch_count
         
         self.res = CouchdbResource(uri, transport=transport, use_proxy=use_proxy,
-            timeout=self.timeout, min_size=min_size, max_size=max_size, 
+            timeout=timeout, min_size=min_size, max_size=max_size, 
             pool_class=pool_class)
         self.uuids = []
         
@@ -258,9 +259,20 @@ class Database(object):
         data = self.res.get(_raw_json=_raw_json)
         return data
         
-    def compact(self):
-        """ compact database"""
-        res = self.res.post('/_compact')
+    def compact(self, dname=None):
+        """ compact database
+        @param dname: string, name of design doc. Usefull to 
+        compact a view.
+        """
+        path = "/_compact"
+        if dname is not None:
+            path = "%s/%s" % (path, self.escape_docid(dname))
+        res = self.res.post(path)
+        return res
+        
+    def view_cleanup(self):
+        res = self.res.post('/_view_cleanup')
+        return res
 
     def flush(self):
         _design_docs = [self[i["id"]] for i in self.all_docs(startkey="_design", endkey="_design/"+u"\u9999")]
@@ -454,8 +466,15 @@ class Database(object):
         if _raw_json:
             return results
         
+        errors = []
         for i, res in enumerate(results):
-            docs[i].update({'_id': res['id'], '_rev': res['rev']})
+            if 'error' in res:
+                errors.append(res)
+            else: 
+                docs[i].update({'_id': res['id'], '_rev': res['rev']})
+        if errors:
+            raise BulkSaveError(errors)
+    
     
     def bulk_delete(self, docs, all_or_nothing=False, _raw_json=False):
         """ bulk delete. 
