@@ -54,11 +54,12 @@ class PreconditionFailed(restkit.ResourceError):
     to a request """
 
 ResourceNotFound = restkit.ResourceNotFound
+RequestFailed = restkit.RequestFailed
 
 class CouchdbResource(restkit.Resource):
 
     def __init__(self, uri="http://127.0.0.1:5984", transport=None, 
-            use_proxy=False, min_size=0, max_size=4, timeout=300,
+            use_proxy=False, timeout=300, min_size=0, max_size=4,
             pool_class=None, **kwargs):
         """Constructor for a `CouchdbResource` object.
 
@@ -160,10 +161,10 @@ class CouchdbResource(restkit.Resource):
             else:
                 error = msg
 
-            if e.status_code == 409:
+            if e.status_int == 409:
                 raise ResourceConflict(error[1], http_code=409,
                         response=e.response)
-            elif e.status_code == 412:
+            elif e.status_int == 412:
                 raise PreconditionFailed(error, http_code=412,
                         response=e.response)
             else:
